==> VirtualBox-7.1.12.tar.bz2: VirtualBox-7.1.12/src/libs/libtpms-0.9.6/src/compiler.h <==
/********************************************************************************/
/*										*/
/*		           Compiler-specific macros				*/
/*                        Written by Stefan Berger				*/
/*		       IBM Thomas J. Watson Research Center			*/
/*										*/
/* (c) Copyright IBM Corporation 2018.						*/
/*										*/
/* All rights reserved.								*/
/* 										*/
/* Redistribution and use in source and binary forms, with or without		*/
/* modification, are permitted provided that the following conditions are	*/
/* met:										*/
/* 										*/
/* Redistributions of source code must retain the above copyright notice,	*/
/* this list of conditions and the following disclaimer.			*/
/* 										*/
/* Redistributions in binary form must reproduce the above copyright		*/
/* notice, this list of conditions and the following disclaimer in the		*/
/* documentation and/or other materials provided with the distribution.		*/
/* 										*/
/* Neither the names of the IBM Corporation nor the names of its		*/
/* contributors may be used to endorse or promote products derived from		*/
/* this software without specific prior written permission.			*/
/* 										*/
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS		*/
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT		*/
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR	*/
/* A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT		*/
/* HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,	*/
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT		*/
/* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,	*/
/* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY	*/
/* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT		*/
/* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE	*/
/* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.		*/
/********************************************************************************/
#ifndef TPMLIB_COMPILER_H
#define TPMLIB_COMPILER_H

#ifndef VBOX
#ifndef __clang__
# define ATTRIBUTE_FORMAT(STRING_IDX, FIRST_TO_CHECK) \
  __attribute__((format (printf, STRING_IDX, FIRST_TO_CHECK)))
#else
# define ATTRIBUTE_FORMAT(STRING_IDX, FIRST_TO_CHECK) \
  __attribute__((__format__ (__printf__, STRING_IDX, FIRST_TO_CHECK)))
#endif
#else
# define ATTRIBUTE_FORMAT(STRING_IDX, FIRST_TO_CHECK)
#endif

#endif /* TPMLIB_COMPILER_H */

==> VirtualBox-7.2.4.tar.bz2: VirtualBox-7.2.4/src/libs/libtpms-0.10.1/src/compiler.h <==
/********************************************************************************/
/*										*/
/*		           Compiler-specific macros				*/
/*                        Written by Stefan Berger				*/
/*		       IBM Thomas J. Watson Research Center			*/
/*										*/
/* (c) Copyright IBM Corporation 2018.						*/
/*										*/
/* All rights reserved.								*/
/* 										*/
/* Redistribution and use in source and binary forms, with or without		*/
/* modification, are permitted provided that the following conditions are	*/
/* met:										*/
/* 										*/
/* Redistributions of source code must retain the above copyright notice,	*/
/* this list of conditions and the following disclaimer.			*/
/* 										*/
/* Redistributions in binary form must reproduce the above copyright		*/
/* notice, this list of conditions and the following disclaimer in the		*/
/* documentation and/or other materials provided with the distribution.		*/
/* 										*/
/* Neither the names of the IBM Corporation nor the names of its		*/
/* contributors may be used to endorse or promote products derived from		*/
/* this software without specific prior written permission.			*/
/* 										*/
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS		*/
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT		*/
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR	*/
/* A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT		*/
/* HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,	*/
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT		*/
/* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,	*/
/* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY	*/
/* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT		*/
/* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE	*/
/* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.		*/
/********************************************************************************/
#ifndef TPMLIB_COMPILER_H
#define TPMLIB_COMPILER_H

#ifndef VBOX
  #ifndef __clang__
  # define ATTRIBUTE_FORMAT(STRING_IDX, FIRST_TO_CHECK) \
    __attribute__((format (printf, STRING_IDX, FIRST_TO_CHECK)))
  #else
  # define ATTRIBUTE_FORMAT(STRING_IDX, FIRST_TO_CHECK) \
    __attribute__((__format__ (__printf__, STRING_IDX, FIRST_TO_CHECK)))
  #endif
  #ifdef __GNUC__ /* gcc and clang */
  # define LIBTPMS_ATTR_UNUSED __attribute__((unused))
  #endif
#else
  # define LIBTPMS_ATTR_UNUSED __attribute__((unused))
  # define ATTRIBUTE_FORMAT(STRING_IDX, FIRST_TO_CHECK)
#endif

#endif /* TPMLIB_COMPILER_H */
